# github-actions-templ

Template repository which includes the following.

Code workflows for basic GitHub Actions like:

- [x] `auto-pr` - Creates PRs for changes in `main` branch
- [x] `auto-labes` - Creates labels for PRs

GitHub customizations update on GitHub console

- [x] `prune-branches` - Deletes branches after PR is merged

## Author

Ramesh Doddi, CTO, iRemote, Inc. https://iremote.ai/

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Notes

DO NOT create standard files like .gitignore, README.md which may interfere with the repository being created.